@@ -2,6 +2,7 @@ import QuantLib as ql
 from .pymodels import *
 from .ql_utils import *
 from .ql_conventions import *
+from .ql_enums import *
 
 
 def get_qlfixedratebond(bond_info: FixedRateBond, setting: BondSetting,
@@ -21,6 +22,25 @@ def get_qlfixedratebond(bond_info: FixedRateBond, setting: BondSetting,
                                 schedule, [bond_info.coupon/100], 
                                 ql_day_count[setting.day_count])
     return qlbond
+
+
+def get_qlbond(bond_info: FixedRateBond, setting: BondSetting,
+                calendar):
+    ql_period = ql.Period(ql_freq_tenor[setting.frequency])
+    day_count = ql_day_count[setting.day_count]
+    schedule = ql.MakeSchedule(datestr_to_qldate(bond_info.issue_date), 
+                                datestr_to_qldate(bond_info.maturity), 
+                                ql_period)
+
+    interest = ql.FixedRateLeg(schedule, 
+                                day_count, 
+                                [100.], 
+                                [bond_info.coupon/100])
+    qlbond = ql.Bond(0, ql.TARGET(), 
+                    datestr_to_qldate(bond_info.issue_date), 
+                    interest)
+    
+    return qlbond
     
 
 def calc_fixbond_structures(value_date: str, bond_info: FixedRateBond, setting: BondSetting,
@@ -65,12 +85,16 @@ def calc_fixbond_structures(value_date: str, bond_info: FixedRateBond, setting:
 
 
 def fixbond_ytm(clean_price: float, 
-                qlbond: ql.QuantLib.FixedRateBond):
-    ytm = qlbond.bondYield(clean_price, 
-                                qlbond.dayCounter(),
+                daycount: DayCount,
+                frequency: Frequency,
+                thebond: ql.QuantLib.Bond):
+    day_count = ql_day_count[daycount.value]
+    freq = ql_frequency[frequency.value]
+    ytm = thebond.bondYield(clean_price, 
+                                day_count,
                                 ql.Compounded,
-                                qlbond.frequency())
-    return ytm
+                                freq)
+    return ytm * 100
 
 
 def bond_functions_cashflows(qlvaluedate:ql.QuantLib.Date, 
